pub struct CallbackAccounts {
pub progress_callback_type: ProgressCallbackType,
pub custom_account_0: Option<Pubkey>,
pub custom_account_1: Option<Pubkey>,
}Expand description
Optional progress-callback accounts for enqueue_to_withdraw and
withdraw_queued_liquidity.
Fields
progress_callback_type: ProgressCallbackTypecustom_account_0: Option<Pubkey>custom_account_1: Option<Pubkey>Implementations
Sourceimpl CallbackAccounts
impl CallbackAccounts
Sourcepub fn from_withdraw_ticket(ticket: &WithdrawTicket) -> Option<Self>
pub fn from_withdraw_ticket(ticket: &WithdrawTicket) -> Option<Self>
Extract callback configuration from a deserialized crate::state::WithdrawTicket.
Returns None if the ticket has no callback (ProgressCallbackType::None).
Sourcepub fn from_withdraw_ticket_data(
data: &[u8],
) -> Result<Option<Self>, AccountDataError>
pub fn from_withdraw_ticket_data( data: &[u8], ) -> Result<Option<Self>, AccountDataError>
Extract callback configuration from raw withdraw ticket account data bytes.
Returns Ok(None) if the ticket has no callback.