pub struct InitObligationArgs {
pub tag: u8,
pub id: u8,
}Fields
tag: u8id: u8Trait Implementations
Sourceimpl BorshDeserialize for InitObligationArgswhere
u8: BorshDeserialize,
impl BorshDeserialize for InitObligationArgswhere
u8: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for InitObligationArgswhere
u8: BorshSerialize,
impl BorshSerialize for InitObligationArgswhere
u8: BorshSerialize,
Sourceimpl Clone for InitObligationArgs
impl Clone for InitObligationArgs
Sourcefn clone(&self) -> InitObligationArgs
fn clone(&self) -> InitObligationArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InitObligationArgs
impl Debug for InitObligationArgs
Sourceimpl Default for InitObligationArgs
impl Default for InitObligationArgs
Sourcefn default() -> InitObligationArgs
fn default() -> InitObligationArgs
Returns the “default value” for a type. Read more
impl Eq for InitObligationArgs
Sourceimpl PartialEq for InitObligationArgs
impl PartialEq for InitObligationArgs
Sourcefn eq(&self, other: &InitObligationArgs) -> bool
fn eq(&self, other: &InitObligationArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for InitObligationArgs