pub struct ObligationOrder {
pub condition_threshold_sf: u128,
pub opportunity_parameter_sf: u128,
pub min_execution_bonus_bps: u16,
pub max_execution_bonus_bps: u16,
pub condition_type: u8,
pub opportunity_type: u8,
pub padding1: [u8; 10],
pub padding2: [u128; 5],
}Fields
condition_threshold_sf: u128opportunity_parameter_sf: u128min_execution_bonus_bps: u16max_execution_bonus_bps: u16condition_type: u8opportunity_type: u8padding1: [u8; 10]padding2: [u128; 5]Trait Implementations
Sourceimpl BorshDeserialize for ObligationOrderwhere
u128: BorshDeserialize,
u16: BorshDeserialize,
u8: BorshDeserialize,
[u8; 10]: BorshDeserialize,
[u128; 5]: BorshDeserialize,
impl BorshDeserialize for ObligationOrderwhere
u128: BorshDeserialize,
u16: BorshDeserialize,
u8: BorshDeserialize,
[u8; 10]: BorshDeserialize,
[u128; 5]: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ObligationOrderwhere
u128: BorshSerialize,
u16: BorshSerialize,
u8: BorshSerialize,
[u8; 10]: BorshSerialize,
[u128; 5]: BorshSerialize,
impl BorshSerialize for ObligationOrderwhere
u128: BorshSerialize,
u16: BorshSerialize,
u8: BorshSerialize,
[u8; 10]: BorshSerialize,
[u128; 5]: BorshSerialize,
Sourceimpl Clone for ObligationOrder
impl Clone for ObligationOrder
Sourcefn clone(&self) -> ObligationOrder
fn clone(&self) -> ObligationOrder
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObligationOrder
impl Debug for ObligationOrder
Sourceimpl Default for ObligationOrder
impl Default for ObligationOrder
Sourcefn default() -> ObligationOrder
fn default() -> ObligationOrder
Returns the “default value” for a type. Read more
impl Eq for ObligationOrder
Sourceimpl PartialEq for ObligationOrder
impl PartialEq for ObligationOrder
Sourcefn eq(&self, other: &ObligationOrder) -> bool
fn eq(&self, other: &ObligationOrder) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ObligationOrder